:orphan:

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _releasenotes:

FileBrowser 4.0 Release Notes
=============================

FileBrowser 4.0 is compatible with Django 4.0 as well as Grappelli 3.0.

Updates
-------

* Compatibility with Django 4.0 and Grappelli 3.0

Update from FileBrowser 3.14.x
------------------------------

* Update Django to 4.0 and check https://docs.djangoproject.com/en/4.0/releases/4.0/
* Update Grappelli to 3.0.x
* Update FileBrowser to 4.0.x
